summaryrefslogtreecommitdiffstats
path: root/kchart/kchartDataEditor.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kchart/kchartDataEditor.cc')
-rw-r--r--kchart/kchartDataEditor.cc18
1 files changed, 9 insertions, 9 deletions
diff --git a/kchart/kchartDataEditor.cc b/kchart/kchartDataEditor.cc
index 9c5de4f9..2bd0230d 100644
--- a/kchart/kchartDataEditor.cc
+++ b/kchart/kchartDataEditor.cc
@@ -204,10 +204,10 @@ kchartDataEditor::kchartDataEditor(TQWidget* parent) :
// Buttons for Inserting / Removing rows & columns
// The icon images are taken from the standard
m_insertRowButton = new TQPushButton( page);
// In 2.0; this is supposed to be just KIcon("name").pixmap(32).
m_insertRowButton->setPixmap( BarIcon( TQString("insert_table_row"),
- KIcon::SizeMedium,
- KIcon::DefaultState,
+ TDEIcon::SizeMedium,
+ TDEIcon::DefaultState,
KChartFactory::global() ) );
//m_insertRowButton = new TQPushButton( i18n("Insert Row") , page);
connect( m_insertRowButton, TQT_SIGNAL( clicked() ),
@@ -215,8 +215,8 @@ kchartDataEditor::kchartDataEditor(TQWidget* parent) :
m_removeRowButton = new TQPushButton( page );
m_removeRowButton->setPixmap( BarIcon( TQString("delete_table_row"),
- KIcon::SizeMedium,
- KIcon::DefaultState,
+ TDEIcon::SizeMedium,
+ TDEIcon::DefaultState,
KChartFactory::global() ) );
//m_removeRowButton = new TQPushButton( i18n("Remove Row") , page);
connect( m_removeRowButton, TQT_SIGNAL( clicked() ),
@@ -224,8 +224,8 @@ kchartDataEditor::kchartDataEditor(TQWidget* parent) :
m_insertColButton = new TQPushButton( page );
m_insertColButton->setPixmap( BarIcon( TQString("insert_table_col"),
- KIcon::SizeMedium,
- KIcon::DefaultState,
+ TDEIcon::SizeMedium,
+ TDEIcon::DefaultState,
KChartFactory::global() ) );
//m_insertColButton = new TQPushButton( i18n("Insert Column") , page);
connect( m_insertColButton, TQT_SIGNAL( clicked() ),
@@ -233,8 +233,8 @@ kchartDataEditor::kchartDataEditor(TQWidget* parent) :
m_removeColButton = new TQPushButton( page );
m_removeColButton->setPixmap( BarIcon( TQString("delete_table_col"),
- KIcon::SizeMedium,
- KIcon::DefaultState,
+ TDEIcon::SizeMedium,
+ TDEIcon::DefaultState,
KChartFactory::global() ) );
//m_removeColButton = new TQPushButton( i18n("Remove Column") , page);
connect( m_removeColButton, TQT_SIGNAL( clicked() ),
@@ -204,10 +204,10 @@ kchartDataEditor::kchartDataEditor(TQWidget* parent) :
// The icon images are taken from the standard
m_insertRowButton = new TQPushButton( page);
- // In 2.0; this is supposed to be just KIcon("name").pixmap(32).
+ // In 2.0; this is supposed to be just TDEIcon("name").pixmap(32).
m_insertRowButton->setPixmap( BarIcon( TQString("insert_table_row"),